Struct WpDrmLeaseV1
pub struct WpDrmLeaseV1 { /* private fields */ }wayland and Linux only.Expand description
a DRM lease
A DRM lease object is used to transfer the DRM file descriptor to the client and manage the lifetime of the lease.
Some time after the wp_drm_lease_v1 object is created, the compositor will reply with the lease request’s result. If the lease request is granted, the compositor will send a lease_fd event. If the lease request is denied, the compositor will send a finished event without a lease_fd event.
See also the Event enum for this interface.
Implementations
impl WpDrmLeaseV1
impl WpDrmLeaseV1
pub fn destroy(&self)
pub fn destroy(&self)
destroys the lease object
The client should send this to indicate that it no longer wishes to use this lease. The compositor should use drmModeRevokeLease on the appropriate file descriptor, if necessary.
Upon destruction, the compositor should advertise the connector for leasing again by sending the connector event through the wp_drm_lease_device_v1 interface.